// +--------------------------------------------------------------------------+
// | BXE                                                                      |
// +--------------------------------------------------------------------------+
// | Copyright (c) 2003,2004 Bitflux GmbH                                     |
// +--------------------------------------------------------------------------+
// | Licensed under the Apache License, Version 2.0 (the "License");          |
// | you may not use this file except in compliance with the License.         |
// | You may obtain a copy of the License at                                  |
// |     http://www.apache.org/licenses/LICENSE-2.0                           |
// | Unless required by applicable law or agreed to in writing, software      |
// | distributed under the License is distributed on an "AS IS" BASIS,        |
// | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
// | See the License for the specific language governing permissions and      |
// | limitations under the License.                                           |
// +--------------------------------------------------------------------------+
// | Author: Christian Stocker <chregu@bitflux.ch>                            |
// +--------------------------------------------------------------------------+
//
// $Id: table.js 939 2004-11-24 21:23:42Z chregu $


HTMLTableCellElement.prototype.TableRemoveRow = function() {
	this.parentNode.parentNode.removeChild(this.parentNode);
}

HTMLTableCellElement.prototype.TableRemoveCol = function() {
	var pos = this.findPosition();
	var table = this.parentNode.parentNode;
	var colpos = 1;
	var row = table.firstChild;
	var colToBeRemoved = null;
	while (row) {
		if (row.nodeType == 1) {
			
			if ( row.localName.toLowerCase() == "tr") {
				var cell = row.findCellPosition(pos);
				if (cell) {
					row.removeChild(cell);
				}
			} else if ( row.localName.toLowerCase() == "col") {
				if (colpos == pos) {
					colToBeRemoved = row;
					
				}
				colpos++;
			}
		}
		row = row.nextSibling;
	}
	if (colToBeRemoved) {
		table.removeChild(colToBeRemoved);
	}
}

HTMLTableCellElement.prototype.TableAppendRow = function () {
	var newRow = this.parentNode.cloneNode(true);
	this.parentNode.parentNode.insertAfter(newRow,this.parentNode);
}

HTMLTableCellElement.prototype.TableAppendCol = function () {
	var pos = this.findPosition();
	var table = this.parentNode.parentNode;
	var row = table.firstChild;
	var colpos = 1;
	while (row) {
		if (row.nodeType == 1) {
			if ( row.localName.toLowerCase() == "tr") {
				var cell = row.findCellPosition(pos);
				if (cell) {
					var newtd = document.createElementNS(XHTMLNS,"td");
					newtd.appendChild(document.createTextNode(STRING_NBSP));
					row.insertBefore(newtd,cell.nextSibling);
				}
			} else if ( row.localName.toLowerCase() == "col") {
				dump (colpos + " ==  " + pos + "\n");
				if (colpos == pos) {
					
					table.insertBefore(document.createElementNS(XHTMLNS, "col"),row.nextSibling);
				}
				colpos++;
			}
		}
		
		row = row.nextSibling;
	}
	
}

HTMLTableCellElement.prototype.findPosition = function () {
	// find position
	var prevSibling = this.previousSibling;
	var pos = 1;
	while(prevSibling) {
		if (prevSibling.nodeType == 1 && prevSibling.localName.toLowerCase() == "td") {
			if (prevSibling.hasAttribute("colspan")) {
				pos += parseInt( prevSibling.getAttribute("colspan"));
			} else {
				pos++;
			}
		}
		prevSibling = prevSibling.previousSibling;
	}
	return pos;
}

HTMLTableCellElement.prototype.TableCellMergeRight = function () {
	var nextSibling = this.nextSibling;
	while (nextSibling && nextSibling.nodeType != 1) {
		nextSibling = nextSibling.nextSibling;
	}
	var child = nextSibling.firstChild;
	while (child) {
		this.appendChild(child);
		child = child.nextSibling;
	}
	this.normalize();
	nextSibling.parentNode.removeChild(nextSibling);
	var colspan = this.getAttribute("colspan");
	if (!colspan) {
		colspan = 1;
	}
	this.setAttribute("colspan", colspan+1);
}



HTMLTableCellElement.prototype.TableCellMergeDown = function () {
	
	var pos = this.findPosition();
	var thisRowspan = 1;
	if (this.hasAttribute("rowspan")) {
		thisRowspan = this.getAttribute("rowspan");
	}
	this.setAttribute("rowspan",thisRowspan+1);	
	
	// find the same cell in the row below..
	var tr = null;
	// find next Row
	
	var nextSibling = this.parentNode.nextSibling
	while(nextSibling) {
		if (nextSibling.nodeType == 1 && nextSibling.localName.toLowerCase() == "tr") {
			tr = nextSibling;
			break;
		}
		nextSibling = nextSibling.nextSibling;
	}
	
	if (!tr) {
		alert("no next table row found");
		return;
	}
	
	nextSibling = tr.firstChild;
	var nextpos = 1;
	while(nextSibling) {
		if (nextSibling.nodeType == 1 && nextSibling.localName.toLowerCase() == "td") {
			if (nextSibling.hasAttribute("colspan")) {
				nextpos += parseInt( nextSibling.getAttribute("colspan"));
			} else {
				nextpos++;
			}
			if (nextpos > pos) {
				break;
			}
		}
		nextSibling = nextSibling.nextSibling;
	}
	
	
	var child = nextSibling.firstChild;
	while (child) {
		this.appendChild(child);
		child = child.nextSibling;
	}
	this.normalize();
	tr.removeChild(nextSibling);
}

HTMLTableCellElement.prototype.TableCellSplitRight = function () {
	
	var cssr = window.getSelection().getEditableRange();
	var ip = documentCreateInsertionPoint(cssr.top, cssr.startContainer, cssr.startOffset);
	ip.splitContainedLine();

	var colspan = this.getAttribute("colspan");
	if (colspan > 2) {
		this.setAttribute("colspan", colspan-1);
	} else {
		this.removeAttribute("colspan");
	}
	var nextSibling = this.nextSibling;
	while (nextSibling && nextSibling.nodeType != 1) {
		nextSibling = nextSibling.nextSibling;
	}
	if (nextSibling) {
		nextSibling.removeAttribute("colspan");
	}
	
}


HTMLTableCellElement.prototype.TableCellSplitDown = function() {
	var pos = this.findPosition();
	var tr = this.parentNode;
	var cssr = window.getSelection().getEditableRange();
	var ip = documentCreateInsertionPoint(cssr.top, cssr.startContainer, cssr.startOffset);
	ip.splitContainedLine();

	var rowspan = this.getAttribute("rowspan");
	if (rowspan > 2) {
		this.setAttribute("rowspan", rowspan-1);
	} else {
		this.removeAttribute("rowspan");
	}
	var nextSibling = this.nextSibling;
	while (nextSibling && nextSibling.nodeType != 1) {
		nextSibling = nextSibling.nextSibling;
	}
	if (nextSibling) {
		nextSibling.removeAttribute("rowspan");
	}
	
	
	var nexttr = tr.nextSibling;
	while (nexttr) {
		if (nexttr.nodeType == 1 && nexttr.localName.toLowerCase() == "tr") {
			var cell = nexttr.findCellPosition(pos-1);
			if (cell) {
				nexttr.insertBefore(nextSibling,cell.nextSibling);
			}
			break;
		}
		nexttr = nexttr.nextSibling;
	}
	
	
}
HTMLTableRowElement.prototype.findCellPosition = function(pos) {
	var cell = this.firstChild;
	var nextpos = 1;
	
	while (cell) {
		if (cell.nodeType == 1 && cell.localName.toLowerCase() == "td") {
			if (nextpos >= pos) {
				return cell;
			}
			if (cell.hasAttribute("colspan")) {
				nextpos += parseInt( cell.getAttribute("colspan"));
			} else {
				nextpos++;
			}
		}
		cell = cell.nextSibling;
	}
	
}

