package org.xmldb.xupdate.lexus.commands;

/*
 *  The XML:DB Initiative Software License, Version 1.0
 *
 *
 * Copyright (c) 2000-2003 The XML:DB Initiative.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        XML:DB Initiative (http://www.xmldb.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "XML:DB Initiative" must not be used to endorse or
 *    promote products derived from this software without prior written
 *    permission. For written permission, please contact info@xmldb.org.
 *
 * 5. Products derived from this software may not be called "XML:DB",
 *    nor may "XML:DB" appear in their name, without prior written
 *    permission of the XML:DB Initiative.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the XML:DB Initiative. For more information
 * on the XML:DB Initiative, please see <http://www.xmldb.org/>.
 */

import org.w3c.dom.Attr;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

import java.util.Hashtable;

/**
 *
 * @version $Id: InsertCommand.java,v 1.7 2003/05/21 13:27:50 jbreedveld Exp $
 * @author <a href="http://www.smb-tec.com">SMB</a>
 */
public abstract class InsertCommand extends CommandObject {

  /* */
  private Node current = null;
  /* */
  protected Node result = null;
  /* */
  private int state = -1;
  /* */
  private InsertStates[] states = null;
  /* */
  private static final int STATE_COUNT = 7;

  /**
   *
   */
  public InsertCommand(Node contextNode) throws Exception {
    super(contextNode);
    states = new InsertStates[STATE_COUNT];
    states[0] = new InsertElement();
    states[1] = new InsertAttribute();
    states[2] = new InsertComment();
    states[3] = new InsertText();
    states[4] = new InsertCDATA();
    states[5] = new InsertProcessingInstruction();
    states[6] = new InsertVariable();
  }


  /**
   *
   */
  public void submitAttributes(Hashtable attributes) {
    if (state < 0) {
      super.submitAttributes(attributes);
    } else {
      states[state].submitAttributes(attributes);
    }
  }


  /**
   *
   */
  public void submitCharacters(String data) {
    if (state < 0) {
      super.submitCharacters(data);
    } else {
      states[state].submitCharacters(data);
    }
  }


  /**
   *
   */
  public boolean submitInstruction(int instruction) throws Exception {
    if (result == null) {
      result = document.createElementNS(null, "temporaryXUpdateTree");
      current = result;
      document.getDocumentElement().appendChild(result);
    }
    if (state >= 0) {
      current = states[state].execute(current);
    }
    switch (instruction) {
      case CommandConstants.INSTRUCTION_ELEMENT:
        state = 0;
        break;
      case CommandConstants.INSTRUCTION_ATTRIBUTE:
        state = 1;
        break;
      case CommandConstants.INSTRUCTION_COMMENT:
        state = 2;
        break;
      case CommandConstants.INSTRUCTION_TEXT:
        state = 3;
        break;
      case CommandConstants.INSTRUCTION_CDATA:
        state = 4;
        break;
      case CommandConstants.INSTRUCTION_PROCESSING_INSTRUCTION:
        state = 5;
        break;
      case CommandConstants.INSTRUCTION_VALUE_OF:
        state = 6;
        break;
      default:
        state = -1;
    }
    if (state >= 0) {
      states[state].reset();
    }
    return state >= 0;
  }


  /**
   *
   */
  public boolean executeInstruction() throws Exception {
    if (state >= 0) {
      current = states[state].execute(current);
      state = -1;
    }
    if (!current.equals(result)) {
      switch (current.getNodeType()) {
        case Node.ATTRIBUTE_NODE:
          current = ((Attr) current).getOwnerElement();
          return true;
        default:
          current = current.getParentNode();
          return true;
      }
    }
    return false;
  }


  /**
   *
   */
  protected void insertAttributes(NamedNodeMap attributes, Node node) throws Exception {
    if (attributes == null) {
      return;
    }
    if (node.getNodeType() != Node.ELEMENT_NODE) {
      throw new Exception("can't append attribute to !");
    }
    int attributesLength = attributes.getLength();
    for (int j = 0; j < attributesLength; j++) {
      Attr attribute = (Attr) attributes.item(j);
      String namespaceURI = attribute.getNamespaceURI();
      ((Element) node).setAttributeNS(namespaceURI, attribute.getNodeName(), attribute.getNodeValue());
    }
  }


  /**
   *
   */
  public abstract Node execute() throws Exception;
}

