package org.xmldb.xupdate.unittests;

/*
 *  The XML:DB Initiative Software License, Version 1.0
 *
 *
 * Copyright (c) 2000-2003 The XML:DB Initiative.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        XML:DB Initiative (http://www.xmldb.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "XML:DB Initiative" must not be used to endorse or
 *    promote products derived from this software without prior written
 *    permission. For written permission, please contact info@xmldb.org.
 *
 * 5. Products derived from this software may not be called "XML:DB",
 *    nor may "XML:DB" appear in their name, without prior written
 *    permission of the XML:DB Initiative.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the XML:DB Initiative. For more information
 * on the XML:DB Initiative, please see <http://www.xmldb.org/>.
 */

/**
 *
 * These unittests test the basic functionality of XUpdate.
 * The list is not complete yet.
 *
 */
public class XUpdateTests extends LexusTestCase {

  public XUpdateTests(String name) {
    super(name);
  }

  /**
   * Remove tests.
   *
   * - Deletion of element nodes
   * - Deletion of attribute nodes
   * - Deletion of text nodes should be added
   * - Deletion of CDATA sections should be added
   * - Deletion of processing instructions should be added
   * - Deletion of comments should be added
   */
  public void testRemove() throws Exception {
    mainTest("testRemove");
  }

  public void testRemoveAttribute() throws Exception {
    mainTest("testRemoveAttribute");
  }

  public void testRemoveText() throws Exception {
    mainTest("testRemoveText");
  }

  /**
   * Insert tests.
   *
   * - Insertion of element nodes before element
   * - Insertion of element nodes after element
   *
   * - Insertion of element nodes with a namespace before element should be added
   * - Insertion of element nodes with a namespace after element
   *
   * - Insertion of text nodes before element should be added
   * - Insertion of text nodes after element
   *
   * - Insertion of attribute nodes before element
   * - Insertion of attribute nodes after element
   *
   * - Insertion of attribute nodes with a namespace before element should be added
   * - Insertion of attribute nodes with a namespace after element should be added
   */
  public void testInsertBefore() throws Exception {
    mainTest("testInsertBefore");
  }

  public void testInsertAfter() throws Exception {
    mainTest("testInsertAfter");
  }

  public void testInsertAfterNS() throws Exception {
    mainTest("testInsertAfterNS");
  }

  public void testTextInsertAfter() throws Exception {
    mainTest("testTextInsertAfter");
  }

  public void testInsertBeforeAttribute() throws Exception {
    mainTest("testInsertBeforeAttribute");
  }

  public void testInsertAfterAttribute() throws Exception {
    mainTest("testInsertAfterAttribute");
  }

  /**
   * Rename tests.
   *
   * - Changing name element nodes
   * - Changing name attribute nodes

   * - Changing name element nodes with a namespace should be added
   * - Changing name attribute nodes with a namespace should be added
   */
  public void testRename() throws Exception {
    mainTest("testRename");
  }

  public void testRenameAttribute() throws Exception {
    mainTest("testRenameAttribute");
  }

  /**
   * Update tests.
   *
   * - Updating element nodes
   * - Updating attribute nodes
   * - Updating CDATA-sections should be added
   * - Updating processing instructions should be added
   *
   * - Updating element nodes with a namespace should be added
   * - Updating attribute nodes with a namespace should be added
   */
  public void testUpdate() throws Exception {
    mainTest("testUpdate");
  }

  public void testUpdateAttribute() throws Exception {
    mainTest("testUpdateAttribute");
  }

  /**
   * Append tests.
   *
   * - Appending element nodes should be added
   * - Appending text nodes should be added
   * - Appending attribute nodes
   * - Appending CDATA sections
   * - Appending processing instructions should be added
   *
   * - Appending element nodes with a namespace should be added
   * - Appending attribute nodes with a namespace should be added
   */
  public void testAppendNS() throws Exception {
    mainTest("testAppendNS");
  }

  public void testAppendAttribute() throws Exception {
    mainTest("testAppendAttribute");
  }

  public void testAppendCDATA() throws Exception {
    mainTest("testAppendCDATA");
  }

  /**
   * Variable tests.
   *
   */
  public void testVariable() throws Exception {
    mainTest("testVariable");
  }

  public void testValueOf() throws Exception {
    mainTest("testValueOf");
  }

  /**
   * test input file with namespace declaration.
   * Does XPath correctly select nodes?
   *
   */
  public void testInputWithNameSpaces() throws Exception {
    mainTest("testInputWithNameSpaces");
  }

  /**
   * Kimbro staken use-cases.
   *
   * http://www.xmldatabases.org/projects/XUpdate-UseCases/
   *
   */
  public void testUseCases() throws Exception {
    mainTest("use-cases_Insert_Element_Before");
    mainTest("use-cases_Insert_Element_After");
    mainTest("use-cases_Append_Element");
    mainTest("use-cases_Insert_Attribute");
    /*
    nodematcher doesn't consider two text-nodes as one
    */
    //mainTest("use-cases_Insert_Text_Content");
    mainTest("use-cases_Insert_XML_Block");
    /*
    Same problem as with inserting attributes,
    inserting the empty text-nodes before document-element causes problems
    */
    //mainTest("use-cases_Insert_Processing_Instruction");
  }
}
